@@ -35,7 +35,7 @@ def changed_message(changed_field, old, new):
                         message += f"field: {field}"
                         old_field = eval('old["fields"]["' + field + '"]')
                         new_field = eval('new.' + field)
-                        message += f", old: {str(old_field)[:50]}, new: {str(new_field)[:50]}\n"
+                        message += f", old: {str(old_field).encode('utf-8', 'ignore')}, new: {str(new_field).encode('utf-8', 'ignore')}\n"
                     except:
                         pass
         if "added" in i:
@@ -44,7 +44,7 @@ def changed_message(changed_field, old, new):
                     message += f"added: {key} - {value}\n"
                 except:
                     pass
-    return message
+    return message.encode('utf-8', 'ignore')
 
 
 class CustomModelAdmin(admin.ModelAdmin):
